/**
  (c) Copyright CERN 2005. All rights not expressly granted are reserved.
icecontrols.support@cern.ch

  SPDX-License-Identifier: LGPL-3.0-only
**/

#uses "fwUnitTestComponentAsserts.ctl"
#uses "unSystemIntegrity/unSendMail.ctl"

//-------------------------------------
void test_unSendMail_setupSuite(){
}

//-------------------------------------
void test_unSendMail_teardownSuite(){
}

//-------------------------------------
void test_hidePassword(){
  //Just to make sure that the password is correctly encrypted as string and not blob
  string sHidden = unSendMail_hidePassword("testPassword", "testKey");
  string sExpected = "E0C571C64E5ED669C0D2365386A8E90B";
  assertEqual(sExpected, sHidden, "Encrypted password is not the expected format");
}

//-------------------------------------
void test_unhidePassword(){
  //Just to make sure that the password decrypted properly in subsequent PVSS versions/patches
  string sClear = unSendMail_unhidePassword("E0C571C64E5ED669C0D2365386A8E90B", "testKey");
  string sExpected = "testPassword";
  assertEqual(sExpected, sClear, "Could not decrypt the password as expected");
}

//-----------------------------------------
void test__unSendMail_dynClearAll_1array(){
  dyn_string a=makeDynString("a","b","c");
  _unSendMail_dynClearAll(a);
  assertTrue( dynlen(a)==0, "The function _unSendMail_dynClearAll did not clear the array as expected");
}

//-----------------------------------------
void test__unSendMail_dynClearAll_3array(){
  dyn_string a=makeDynString("a","b","c");
  dyn_int b= makeDynInt(1,2,3);
  dyn_bool c = makeDynBool(true, false, true);
  _unSendMail_dynClearAll(a,b,c);
  assertTrue( dynlen(a)==0, "The function _unSendMail_dynClearAll did not clear the array a as expected");
  assertTrue( dynlen(b)==0, "The function _unSendMail_dynClearAll did not clear the array b as expected");
  assertTrue( dynlen(c)==0, "The function _unSendMail_dynClearAll did not clear the array c as expected");
}

//-----------------------------------------
void test__unSendMail_dynClearAll_3arrayAndNotArray(){
  dyn_string a=makeDynString("a","b","c");
  dyn_int b= makeDynInt(1,2,3);
  dyn_bool c = makeDynBool(true, false, true);
  string s="NotTouched";
  _unSendMail_dynClearAll(a, b, c, s);
  assertTrue( dynlen(a)==0, "The function _unSendMail_dynClearAll did not clear the array a as expected");
  assertTrue( dynlen(b)==0, "The function _unSendMail_dynClearAll did not clear the array b as expected");
  assertTrue( dynlen(c)==0, "The function _unSendMail_dynClearAll did not clear the array c as expected");
  assertEqual( "NotTouched", s, "The function _unSendMail_dynClearAll modified a string variable while it should leave it untouched");
}


//-------------------------------------------
void test_unSendMail_parseConfigMailSettings_Default(){
  dyn_string dsSettings;
  dynAppend(dsSettings, "unSystemIntegrity");
  dyn_string dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword;
  dyn_bool dbUseSsl;
  unSendMail_parseConfigMailSettings(dsSettings, dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword, dbUseSsl);
  assertEqual(makeDynString("unSystemIntegrity"), dsType, "Type is not the excepted one");
  assertEqual(makeDynString(""), dsSender, "Sender is not the excepted one");
  assertEqual(makeDynString(""), dsReceiver, "Receivers are not the excepted one");
  assertEqual(makeDynString(c_MailDomain), dsDomain, "Domain is not the excepted one");
  assertEqual(makeDynString(c_MailServer), dsSmtp, "SMTP server is not the excepted one");
  assertEqual(makeDynString(unSendMail_getHTMLLink()), dsLink, "Link is not the excepted one");
  assertEqual(makeDynString(c_iMax), dsMax, "Maximum number of mails sent per day is not the excepted one");
  assertEqual(makeDynString(""), dsUser, "Username is not the excepted one");
  assertEqual(makeDynString(""), dsPassword, "Passowrd is not the excepted one");//password in clear text
  assertEqual(makeDynBool(FALSE), dbUseSsl, "SSL/TLS setting is not the excepted one");
}

//-------------------------------------------
void test_unSendMail_parseConfigMailSettings_OldFormat(){
  dyn_string dsSettings;
  dynAppend(dsSettings, "unSystemIntegrity~gmail.com~smtp.gmail.com:587~test01@cern.ch~jean-charles.tournier@cern.ch;tournier@cern.ch");
  dyn_string dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword;
  dyn_bool dbUseSsl;
  unSendMail_parseConfigMailSettings(dsSettings, dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword, dbUseSsl);
  assertEqual(makeDynString("unSystemIntegrity"), dsType, "Type is not the excepted one");
  assertEqual(makeDynString("test01@cern.ch"), dsSender, "Sender is not the excepted one");
  assertEqual(makeDynString("jean-charles.tournier@cern.ch;tournier@cern.ch"), dsReceiver, "Receivers are not the excepted one");
  assertEqual(makeDynString("gmail.com"), dsDomain, "Domain is not the excepted one");
  assertEqual(makeDynString("smtp.gmail.com:587"), dsSmtp, "SMTP server is not the excepted one");
  assertEqual(makeDynString(""), dsLink, "Link is not the excepted one");
  assertEqual(makeDynString(c_iMax), dsMax, "Maximum number of mails sent per day is not the excepted one");
  assertEqual(makeDynString(""), dsUser, "Username is not the excepted one");
  assertEqual(makeDynString(""), dsPassword, "Passowrd is not the excepted one");//password in clear text
  assertEqual(makeDynBool(FALSE), dbUseSsl, "SSL/TLS setting is not the excepted one");
}

//-------------------------------------------
void test_unSendMail_parseConfigMailSettings_WithSmtpSettings(){
  dyn_string dsSettings;
  dynAppend(dsSettings, "unSystemIntegrity~gmail.com~smtp.gmail.com:587~test01@cern.ch~jean-charles.tournier@cern.ch;tournier@cern.ch~https://cosmos-grafana.cern.ch/d/jnBohMDGz/bec-details?refresh=30s&orgId=1&var-host=CCC7~250~jeancharles.tournier~D1F17E5685E28FC1E3094A0166E7450E~TRUE");
  dyn_string dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword;
  dyn_bool dbUseSsl;
  unSendMail_parseConfigMailSettings(dsSettings, dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword, dbUseSsl);
  assertEqual(makeDynString("unSystemIntegrity"), dsType, "Type is not the excepted one");
  assertEqual(makeDynString("test01@cern.ch"), dsSender, "Sender is not the excepted one");
  assertEqual(makeDynString("jean-charles.tournier@cern.ch;tournier@cern.ch"), dsReceiver, "Receivers are not the excepted one");
  assertEqual(makeDynString("gmail.com"), dsDomain, "Domain is not the excepted one");
  assertEqual(makeDynString("smtp.gmail.com:587"), dsSmtp, "SMTP server is not the excepted one");
  assertEqual(makeDynString("https://cosmos-grafana.cern.ch/d/jnBohMDGz/bec-details?refresh=30s&orgId=1&var-host=CCC7"), dsLink, "Link is not the excepted one");
  assertEqual(makeDynString("250"), dsMax, "Maximum number of mails sent per day is not the excepted one");
  assertEqual(makeDynString("jeancharles.tournier"), dsUser, "Username is not the excepted one");
  assertEqual(makeDynString(""), dsPassword, "Passowrd is not the excepted one");//password in clear text
  assertEqual(makeDynBool(TRUE), dbUseSsl, "SSL/TLS setting is not the excepted one");
}

//-------------------------------------------
void test_unSendMail_parseConfigMailSettings_WithoutSmtpSettings(){
  dyn_string dsSettings;
  dynAppend(dsSettings, "unSystemIntegrity~gmail.com~smtp.gmail.com:587~test01@cern.ch~jean-charles.tournier@cern.ch;tournier@cern.ch~https://cosmos-grafana.cern.ch/d/jnBohMDGz/bec-details?refresh=30s&orgId=1&var-host=CCC7~250");
  dyn_string dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword;
  dyn_bool dbUseSsl;
  unSendMail_parseConfigMailSettings(dsSettings, dsType, dsSender, dsReceiver, dsDomain, dsSmtp, dsLink, dsMax, dsUser, dsPassword, dbUseSsl);
  assertEqual(makeDynString("unSystemIntegrity"), dsType, "Type is not the excepted one");
  assertEqual(makeDynString("test01@cern.ch"), dsSender, "Sender is not the excepted one");
  assertEqual(makeDynString("jean-charles.tournier@cern.ch;tournier@cern.ch"), dsReceiver, "Receivers are not the excepted one");
  assertEqual(makeDynString("gmail.com"), dsDomain, "Domain is not the excepted one");
  assertEqual(makeDynString("smtp.gmail.com:587"), dsSmtp, "SMTP server is not the excepted one");
  assertEqual(makeDynString("https://cosmos-grafana.cern.ch/d/jnBohMDGz/bec-details?refresh=30s&orgId=1&var-host=CCC7"), dsLink, "Link is not the excepted one");
  assertEqual(makeDynString("250"), dsMax, "Maximum number of mails sent per day is not the excepted one");
  assertEqual(makeDynString(""), dsUser, "Username is not the excepted one");
  assertEqual(makeDynString(""), dsPassword, "Passowrd is not the excepted one");//password in clear text
  assertEqual(makeDynBool(FALSE), dbUseSsl, "SSL/TLS setting is not the excepted one");
}